@@ -27,7 +27,7 @@ int main()
   using namespace __gnu_test;
 
   // cplus-dem FAIL
-  verify_demangle("_Z1fPKM1AFivE", "f(int (A::* const*)())");
+  verify_demangle("_Z1sPA37_iPS0_", "s(int (*) [37], int (**) [37])");
 
   return 0;
 }
